@@ -1,38 +1,27 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
+"""minos.networks.handlers module."""
 from .abc import (
-    Consumer,
     Handler,
     HandlerSetup,
 )
 from .command_replies import (
-    CommandReplyConsumer,
-    CommandReplyConsumerService,
     CommandReplyHandler,
     CommandReplyHandlerService,
 )
 from .commands import (
-    CommandConsumer,
-    CommandConsumerService,
     CommandHandler,
     CommandHandlerService,
 )
+from .consumers import (
+    Consumer,
+)
 from .dynamic import (
     DynamicHandler,
-    DynamicReplyHandler,
-    ReplyHandlerPool,
+    DynamicHandlerPool,
 )
 from .entries import (
     HandlerEntry,
 )
 from .events import (
-    EventConsumer,
-    EventConsumerService,
     EventHandler,
     EventHandlerService,
 )
@@ -41,3 +30,6 @@ from .messages import (
     HandlerResponse,
     HandlerResponseException,
 )
+from .services import (
+    ConsumerService,
+)
