@@ -11,6 +11,10 @@ from __future__ import (
 
 from typing import (
     Any,
+    Optional,
+)
+from uuid import (
+    UUID,
 )
 
 from ..messages import (
@@ -34,6 +38,13 @@ class HandlerRequest(Request):
     def __repr__(self) -> str:
         return f"{type(self).__name__}({self.raw!r})"
 
+    @property
+    def user(self) -> Optional[UUID]:
+        """
+        Returns the UUID of the user making the Request.
+        """
+        return getattr(self.raw, "user", None)
+
     async def content(self, **kwargs) -> Any:
         """Request content.
 
